% Diese Datei stellt die LaTeX-Dokumentenklasse "sisart" bereit. Mit ihr
% knnen Autoren der Zeitschrift "Stochastik in der Schule" ihre
% Beitrge setzen.

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{sisart}[%
2001/01/27 %
Dokumentenklasse fuer Artikel der Zeitschrift Stochastik in der Schule]
% Version: 1.01
% Autor: 
% Marcus Otto
% Institut fr Mathematik und Informatik
% Pdagogische Hochschule Ludwigsburg
% http://www.ph-ludwigsburg.de/mathematik
% Copyright (C) 2001 Marcus Otto
% Alle Rechte liegen beim Autor

% nderungen 
% zur Version 1.00
% Zweispaltiger Satz mit Titel vor dem Laden von natbib (mo,20.01.2001)
% Statt Literaturverweisen im Autor(Jahr)-Stil knnen mit der Option 
% numlit nummerierte Verweise erzeugt werden. (mo,20.01.2001)
% Literatureintrge werden ohne Abstand gesetzt (mo,20.01.2001)
% zur Version 1.01
% \end{multicols} vor dem Laden von natbib einfuegen (mo,27.01.2001)


% Paket fr hhere Ablaufsstrukturen (z.Z. nicht bentigt)
%\RequirePackage{ifthen}

% Diese Angabe muss vor dem Laden von natbib stehen (mo,27.01.2001)
\AtEndDocument{\end{multicols}}

% Die Schriftart fr berschriften ist TimesNewRoman
\newcommand{\headingsfont}{\rmfamily}
% Als Alternative kann mit der Option sansserif eine serifenlose
% Schrift benutzt werden.
\DeclareOption{sansserif}{\renewcommand{\headingsfont}{\sffamily}}

% Statt Literaturverweisen im Autor(Jahr)-Stil knnen mit der Option 
% numlit nummerierte Verweise erzeugt werden. (mo,20.01.2001)
\DeclareOption{numlit}{\PassOptionsToPackage{numbers}{natbib}}

% Optionen an Basis-Klasse weiterleiten
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{scrartcl}}

% Optionen verarbeiten
\ProcessOptions\relax

% Diese Klasse basiert auf der Artikelklasse des Pakets koma-script
\LoadClass[%
a4paper,        % Papierformat DIN A4
11pt,           % Gre der Grundschrift
normalheadings, % mittlere berschriftengre (wird weiter unten angepasst)
twoside%,       % zweiseitiger Satz 
%twocolumn,     % zweispaltiger Satz (wird durch das Paket multicol ersetzt)
%pointlessnumbers%, % ist neuestens bereits voreingestellt
]{scrartcl}

% bentigte Zusatzpakete
\RequirePackage{times,mathptm}  % Grundschrift TimesNewRoman (auch in Formeln)
\RequirePackage{fancyhdr}       % Kopf- und Fuzeilen-Anpassung 
\RequirePackage[german]{fancyref} % Verweisvarianten
\RequirePackage{ngerman}        % Worttrennung fr neue dt. Rechtschreibung
\RequirePackage{graphicx}         % Verarbeitung von eingebetteten Bildern
\RequirePackage{parskip}        % Absatzformat (abgesetzt, nicht eingezogen)
\RequirePackage{multicol}       % mehrspaltiger Satz
\RequirePackage{url}            % Internet-Adressen setzen
\RequirePackage{capt-of}        % zustzliche Bild- und Tafelunterschriften
\RequirePackage{natbib}         % Literaturangaben im Autor(Jahr)-Stil

%\usepackage[T1]{fontenc} % Europische Schriftstze (z.Z. nicht ntig)
%\usepackage{textcomp}    % Europische Sonderzeichen (z.Z. nicht ntig)

% Seitenlayout
\oddsidemargin-0.86cm  % Innenrand: 1.7cm; Auenrand: 2.3cm 
\evensidemargin-0.26cm
\textwidth17cm         % Spaltenbreite: 8.1cm
\columnsep0.8cm        % Spaltenabstand: 0.8cm

\topmargin-1.56cm      % oberer Rand: 2.0cm; unterer Rand: 2.4cm
\headsep11pt           % Kopfzeile: 1.0cm vom Rand
\textheight25.2cm
\footskip0.9cm         % Fuzeile: 1.5cm vom Rand

% Kopf- und Fusszeile festlegen
% normale Seiten
% Trennlinien
\renewcommand{\headrulewidth}{0pt}   % keine Trennlinie in der Kopfzeile
\renewcommand{\footrulewidth}{0.4pt} % eine Trenlinie in der Fuzeile
% Kopfzeile leer
% Fuzeile
% Innen: Autor bzw. Kurztitel; Auen: Seitennummer
\fancyhf{}
\fancyfoot[LE,RO]{\sffamily\thepage}
\fancyfoot[LO]{\sffamily\footnotesize\sisshorttitle}
\fancyfoot[RE]{\sffamily\footnotesize\sisshortauthor}
% Kopf- und Fusszeile fr erste Seite festlegen
\fancypagestyle{plain}{%
% Kopfzeile leer
% Fuzeile
% Innen: Heftnummer + Seitenzahl; Auen: Seitennummer
\fancyhf{}
\fancyfoot[LO,RE]{%
{\sffamily\footnotesize\sisissue~S.\,\thepage--\pageref{art:endpage}}}
\fancyfoot[LE,RO]{\sffamily\thepage}
}
% Heftausgabe und Kurztitel/Kurzautor
\newcommand{\sisissue}{Stochastik in der Schule XX\,(XXXX)\,X}
\newcommand{\sisshorttitle}{}
\newcommand{\sisshortauthor}{}
% Kopf- und Fuzeile einschalten
\pagestyle{fancy}

% Zweispaltiger Satz mit Titel
% Eine Angabe muss vor dem Laden von natbib stehen (mo,27.01.2001)
\AtBeginDocument{%
\thispagestyle{plain}
\begin{multicols}{2}[%
{{\raggedright%
\sistitle\\[15pt]
\sisauthor\\[-3pt]
\hrulefill\\[12pt]}}]
}
\AtEndDocument{%
\label{art:endpage}}
% Titeltexte
\newcommand{\sistitle}{\titelgroesse\sectfont\@title}
\newcommand{\sisauthor}{\large\sectfont\scshape\mdseries\@author}

% berschriften
% leider sind die Layoutvorgaben und die Standardimplementierung der
% berschriften nicht miteinander vertrglich. Daher wird das Makro
% @startsection und seine Untermakros fr unsere Zwecke abgewandelt.
% @sisstartsection
\def\@sisstartsection#1#2#3#4#5#6{%
  \if@noskipsec \leavevmode \fi
  \par
  \@tempskipa #4\relax
  \@afterindenttrue
  \ifdim \@tempskipa <\z@
    \@tempskipa -\@tempskipa \@afterindentfalse
  \fi
  \if@nobreak
    \everypar{}%
  \else
    \addpenalty\@secpenalty\addvspace\@tempskipa
  \fi 
  \@ifstar
    {\@sisssect{#3}{#4}{#5}{#6}}%
    {\@dblarg{\@sissect{#1}{#2}{#3}{#4}{#5}{#6}}}}
% @sissect
\def\@sissect#1#2#3#4#5#6[#7]#8{%
  \ifnum #2>\c@secnumdepth
    \let\@svsec\@empty
  \else
    \refstepcounter{#1}%
    \protected@edef\@svsec{\@seccntformat{#1}\relax}%
  \fi
  \@tempskipa #5\relax
  \ifdim \@tempskipa>\z@
    \begingroup
      #6{%
        \@hangfrom{\hskip #3\relax\@svsec}%
          \interlinepenalty \@M #8\@@par}%
    \endgroup
    \csname #1mark\endcsname{#7}%
    \addcontentsline{toc}{#1}{%
      \ifnum #2>\c@secnumdepth \else
        \protect\numberline{\csname the#1\endcsname}%
      \fi
      #7}%
  \fi
  \@sisxsect{#5}}
% @sisxsect
\def\@sisxsect#1{%
  \@tempskipa #1\relax
  \ifdim \@tempskipa>\z@
    \par \nobreak
% Hier sitzt der eigentliche beltter, leider im innersten Makro
% Wir ndern \vskip auf -\medskipamount um \par zu kompensieren
% \@tempskipa kann selbst leider nicht negativ werden
    \vskip -\smallskipamount%\@tempskipa
    \@afterheading
  \fi
  \ignorespaces}
% @sisssect
\def\@sisssect#1#2#3#4#5{%
  \@tempskipa #3\relax
  \ifdim \@tempskipa>\z@
    \begingroup
      #4{%
        \@hangfrom{\hskip #1}%
          \interlinepenalty \@M #5\@@par}%
    \endgroup
  \fi
  \@sisxsect{#3}}
% Die Abstnde mssen angepasst werden
% auerdem in einem Fall die Schriftgroesse
% Abschnittsberschriften haben 12pt Abstand nach oben und 3pt Abstand
% nach unten; Schriftgre ist 13pt, Schnitt: fett
\renewcommand\section{\@sisstartsection{section}{1}{\z@}%
  {-6pt \@plus -1ex \@minus -.2ex}%
  {0.001pt \@plus.2ex}%
  {\raggedsection\normalfont\uegroesse\sectfont}}
% Untergeordnete berschriften haben 6pt Abstand nach oben und 3pt
% Abstand nach unten; Schriftgre ist 11pt, Schnitt: fett
\renewcommand\subsection{\@sisstartsection{subsection}{2}{\z@}%
  {-0.001pt\@plus -1ex \@minus -.2ex}%
  {0.001pt \@plus .2ex}%
  {\raggedsection\normalfont\size@subsection\sectfont}}
% Zweifach untergeordnete berschriften haben 6pt Abstand nach oben
% und 3pt Abstand nach unten; Schriftgre ist 11pt, Schnitt: normal
\renewcommand\subsubsection{\@sisstartsection{subsubsection}{3}{\z@}%
  {-0.001pt\@plus -1ex \@minus -.2ex}%
  {0.001pt \@plus .2ex}%
  {\raggedsection\normalfont\size@subsubsection\sectfont\mdseries}}
% zwei zustzliche Schriftgren sind ntig
% fr Titel (15pt) und Abschnittsberschriften (13pt)
\newcommand\titelgroesse{\@setfontsize\titelgroesse{15}{19.6}}
\newcommand\uegroesse{\@setfontsize\titelgroesse{13}{16}}
% Die Schriftart fr berschriften ist TimesNewRoman, fett
\renewcommand{\sectfont}{\headingsfont\bfseries}

% Zusammenfassung (Abstract)
\renewenvironment{abstract}{%
\begingroup\itshape\textbf{\abstractname{}:}}{\endgroup}

% Abbildungen werden mit Abb. bezeichnet
\renewcommand{\figurename}{Abb.}
\renewcommand*{\Freffigname}{Abb.}
% Tabellen werden analog mit Tab. bezeichnet
\renewcommand{\tablename}{Tab.}
\renewcommand*{\Freftabname}{Tab.}
% Verkrzter Abstand zwischen Abb. und Nummer
% korrigier fehlerhafte tight-Option von fancyref 
\renewcommand*{\fancyrefdefaultspacing}{\fancyreftightspacing}
% Umgebung fr einspaltige Abb./Tab.
% Legenden mit \captionof{figure}{Text} oder table analog
\newenvironment{minifigtab}{
\vspace*{\floatsep}
\begin{minipage}{8.1cm}
}{
\end{minipage}
\vspace*{\floatsep}
}

% Einige neue Befehle um "Computertexte" zu setzen
\newcommand\email{\begingroup \small\Url}
\newcommand\www{\begingroup \small\Url}
\newcommand\directory{\begingroup \small\Url}

% Literatureintrge werden ohne Abstand gesetzt (mo,20.01.2001)
\setlength{\bibsep}{0pt}

% Anschrift des/der Verfasser/s/in/innen
\newenvironment{authoraddress}[1][Anschrift des Verfassers]{%
\medskip\begin{flushleft}#1\\}{\end{flushleft}}
